"use strict";

var _chai = require("chai");

var _mocha = require("mocha");

var _graphql = require("graphql");

var _getQueryFacts = require("../getQueryFacts");

/**
 *  Copyright (c) Facebook, Inc. and its affiliates.
 *
 *  This source code is licensed under the MIT license found in the
 *  LICENSE file in the root directory of this source tree.
 */
(0, _mocha.describe)('collectVariables', function () {
  var TestType = new _graphql.GraphQLObjectType({
    name: 'Test',
    fields: {
      id: {
        type: _graphql.GraphQLID
      },
      string: {
        type: _graphql.GraphQLString
      },
      int: {
        type: _graphql.GraphQLInt
      },
      float: {
        type: _graphql.GraphQLFloat
      },
      boolean: {
        type: _graphql.GraphQLBoolean
      }
    }
  });
  var TestSchema = new _graphql.GraphQLSchema({
    query: TestType
  });
  (0, _mocha.it)('returns an empty object if no variables exist', function () {
    var variableToType = (0, _getQueryFacts.collectVariables)(TestSchema, (0, _graphql.parse)('{ id }'));
    (0, _chai.expect)(variableToType).to.deep.equal({});
  });
  (0, _mocha.it)('collects variable types from a schema and query', function () {
    var variableToType = (0, _getQueryFacts.collectVariables)(TestSchema, (0, _graphql.parse)("\n      query ($foo: Int, $bar: String) { id }\n    "));
    (0, _chai.expect)(Object.keys(variableToType)).to.deep.equal(['foo', 'bar']);
    (0, _chai.expect)(variableToType.foo).to.equal(_graphql.GraphQLInt);
    (0, _chai.expect)(variableToType.bar).to.equal(_graphql.GraphQLString);
  });
  (0, _mocha.it)('collects variable types from multiple queries', function () {
    var variableToType = (0, _getQueryFacts.collectVariables)(TestSchema, (0, _graphql.parse)("\n      query A($foo: Int, $bar: String) { id }\n      query B($foo: Int, $baz: Float) { id }\n    "));
    (0, _chai.expect)(Object.keys(variableToType)).to.deep.equal(['foo', 'bar', 'baz']);
    (0, _chai.expect)(variableToType.foo).to.equal(_graphql.GraphQLInt);
    (0, _chai.expect)(variableToType.bar).to.equal(_graphql.GraphQLString);
    (0, _chai.expect)(variableToType.baz).to.equal(_graphql.GraphQLFloat);
  });
});